ExternalHandlerResource

Struct ExternalHandlerResource 

pub struct ExternalHandlerResource {
    pub url: String,
    pub port: u16,
    pub capture_file: Option<PathBuf>,
    /* private fields */
}
External handler server resource for testing handler transforms

Fields

url: String

The base URL of the handler server (e.g., “http://127.0.0.1:8080”)

port: u16

The port the server is listening on

capture_file: Option<PathBuf>

Path to the capture file (if any)

Implementations

Source

impl ExternalHandlerResource

pub async fn new() -> Result<Self>

Start a new external handler server on an available port

pub async fn with_capture_file(capture_file: Option<PathBuf>) -> Result<Self>

Start a new external handler server with request capture to a file

pub fn slim_handler_url(&self) -> String

Get the URL for the slim single-row handler

pub fn slim_handler_envelope_url(&self) -> String

Get the URL for the slim single-row handler with envelope

pub fn slim_batch_handler_url(&self) -> String

Get the URL for the slim batch handler

pub fn slim_batch_handler_envelope_url(&self) -> String

Get the URL for the slim batch handler with envelope

pub fn passthrough_handler_url(&self) -> String

Get the URL for the passthrough handler

pub fn request_count(&self) -> usize

Get the number of requests received

pub fn get_requests(&self) -> Vec<CapturedHandlerRequest>

Get all captured requests

pub fn read_captured_file(&self) -> Result<Vec<CapturedHandlerRequest>>

Read captured requests from the file (if configured)