PrometheusResource

Struct PrometheusResource 

pub struct PrometheusResource {
    pub url: String,
    pub query_endpoint: String,
    pub ingestion_endpoint: String,
}
Resource for querying Prometheus metrics

Fields

url: String

Base URL for Prometheus (e.g., http://localhost:30090)

query_endpoint: String

Query endpoint (e.g., http://localhost:30090/api/v1/query)

ingestion_endpoint: String

Metrics ingestion endpoint for OTLP (e.g., http://localhost:30090/api/v1/otlp/v1/metrics)

Implementations

Source

impl PrometheusResource

pub fn new(base_url: &str) -> Self

Create a new Prometheus resource from a base URL

pub async fn query(&self, query: &str) -> Result<Option<f64>>

Query Prometheus for a metric value

pub async fn query_count(&self, query: &str) -> Result<Option<u64>>

Query for a metric and return as u64

pub fn output_rows_query(node_id: &str, instance_id: Option<&str>) -> String

Build a query for output rows total metric

pub fn input_rows_query(node_id: &str, instance_id: Option<&str>) -> String

Build a query for input rows total metric

pub fn elapsed_compute_query(node_id: &str, instance_id: Option<&str>) -> String

Build a query for elapsed compute metric

pub fn checkpoint_coordinator_query( metric_name: &str, instance_id: Option<&str>, ) -> String

Build a query for a checkpoint coordinator metric (counter total). Coordinator metrics use id="checkpoint_coordinator".

pub fn checkpoint_histogram_query( metric_name: &str, node_id: &str, instance_id: Option<&str>, ) -> String

Build a query for a checkpoint histogram metric (sum) by node id.

pub async fn wait_for_metric_at_least( &self, query: &str, min_value: u64, timeout_secs: u64, poll_interval_ms: u64, ) -> Result<u64>

Wait for a metric to reach at least a certain value Returns the actual value when the threshold is reached

pub async fn assert_metric_at_least( &self, query: &str, expected: u64, timeout_secs: u64, ) -> Result<()>

Assert that a metric reaches at least a certain value