SqsResource

Struct SqsResource 

pub struct SqsResource {
    pub endpoint_url: String,
    pub region: String,
    pub queue_name: String,
    pub queue_url: String,
    /* private fields */
}
SQS resource manager

Fields

endpoint_url: String

SQS-compatible endpoint URL (e.g. ElasticMQ)

region: String

AWS region (default: us-east-1)

queue_name: String

Name of the isolated SQS queue

queue_url: String

URL of the created SQS queue

Implementations

Source

impl SqsResource

pub async fn new(endpoint_url: &str, queue_name: &str) -> Result<Self>

Create a new SQS resource with an isolated queue

pub async fn send_message(&self, body: &str) -> Result<()>

Send a single message to the queue

pub async fn receive_messages(&self, max_messages: i32) -> Result<Vec<String>>

Receive messages from the queue

Returns a list of message bodies. Uses long polling with a wait time of up to 5 seconds.

pub async fn receive_all_messages( &self, max_messages: usize, max_wait: Duration, ) -> Result<Vec<String>>

Receive all available messages from the queue, polling until no more messages arrive.

This is useful for verification in e2e tests where we want to read all messages that have been written to the queue.

pub async fn get_message_count(&self) -> Result<i64>

Get the approximate number of messages in the queue

pub async fn cleanup(&self) -> Result<()>

Delete the queue (can be called explicitly if needed)