WebhookResource

Struct WebhookResource 

pub struct WebhookResource {
    pub url: String,
    pub port: u16,
    /* private fields */
}
Webhook server resource for capturing HTTP requests

Fields

url: String

The base URL of the webhook server (e.g., “http://127.0.0.1:8080”)

port: u16

The port the server is listening on

Implementations

Source

impl WebhookResource

pub async fn new() -> Result<Self>

Start a new webhook server on an available port

pub async fn new_with_response_plan( response_plan: Vec<StatusCode>, ) -> Result<Self>

Start a new webhook server with a scripted sequence of response statuses.

pub fn webhook_url(&self) -> String

Get the URL for the webhook endpoint

pub fn request_count(&self) -> usize

Get the number of requests received

pub fn get_requests(&self) -> Vec<CapturedRequest>

Get all captured requests

pub fn get_request_bodies_as_string(&self) -> Vec<String>

Get all captured request bodies as strings (for JSON verification)

pub fn get_request_bodies_as_json(&self) -> Vec<Value>

Parse all captured request bodies as JSON

pub async fn wait_for_requests(&self, count: usize, timeout: Duration) -> bool

Wait for at least N requests with a timeout