Module streamling

Module streamling 

Streamling binary execution helpers.

Structs

StreamlingOutput
Output from running streamling with captured stdout/stderr

Functions

run_streamling
Run the streamling binary with the given pipeline file
run_streamling_raw
Run streamling and return raw output, even on failure
run_streamling_with_capture
Run streamling and capture stdout/stderr for inspection
run_streamling_with_capture_and_limit
Run streamling with capture and a record limit
run_streamling_with_limit
Run streamling and wait for it to process a specific number of records This is useful for tests that need streamling to run until a condition is met