run_streamling_raw

Function run_streamling_raw 

pub async fn run_streamling_raw(
    pipeline_path: &Path,
    binary_path: Option<&Path>,
    env_vars: &[(String, String)],
    extra_args: &[String],
) -> Result<StreamlingOutput>
Run streamling and return raw output, even on failure

Unlike run_streamling_with_capture, this function returns the output regardless of the exit status. This is useful for tests that need to inspect error messages from failed pipeline runs.