pub struct SqsResource {
pub endpoint_url: String,
pub region: String,
pub queue_name: String,
pub queue_url: String,
/* private fields */
}Expand description
SQS resource manager
Fields
endpoint_url: StringSQS-compatible endpoint URL (e.g. ElasticMQ)
region: StringAWS region (default: us-east-1)
queue_name: StringName of the isolated SQS queue
queue_url: StringURL of the created SQS queue
Implementations
Sourceimpl SqsResource
impl SqsResource
Sourcepub async fn new(endpoint_url: &str, queue_name: &str) -> Result<Self>
pub async fn new(endpoint_url: &str, queue_name: &str) -> Result<Self>
Create a new SQS resource with an isolated queue
Sourcepub async fn send_message(&self, body: &str) -> Result<()>
pub async fn send_message(&self, body: &str) -> Result<()>
Send a single message to the queue
Sourcepub async fn receive_messages(&self, max_messages: i32) -> Result<Vec<String>>
pub async fn receive_messages(&self, max_messages: i32) -> Result<Vec<String>>
Receive messages from the queue
Returns a list of message bodies. Uses long polling with a wait time of up to 5 seconds.
Sourcepub async fn receive_all_messages(
&self,
max_messages: usize,
max_wait: Duration,
) -> Result<Vec<String>>
pub async fn receive_all_messages( &self, max_messages: usize, max_wait: Duration, ) -> Result<Vec<String>>
Receive all available messages from the queue, polling until no more messages arrive.
This is useful for verification in e2e tests where we want to read all messages that have been written to the queue.
Sourcepub async fn get_message_count(&self) -> Result<i64>
pub async fn get_message_count(&self) -> Result<i64>
Get the approximate number of messages in the queue