pub struct WebhookResource {
pub url: String,
pub port: u16,
/* private fields */
}Expand description
Webhook server resource for capturing HTTP requests
Fields
url: StringThe base URL of the webhook server (e.g., “http://127.0.0.1:8080”)
port: u16The port the server is listening on
Implementations
Sourceimpl WebhookResource
impl WebhookResource
Sourcepub async fn new_with_response_plan(
response_plan: Vec<StatusCode>,
) -> Result<Self>
pub async fn new_with_response_plan( response_plan: Vec<StatusCode>, ) -> Result<Self>
Start a new webhook server with a scripted sequence of response statuses.
Sourcepub fn webhook_url(&self) -> String
pub fn webhook_url(&self) -> String
Get the URL for the webhook endpoint
Sourcepub fn request_count(&self) -> usize
pub fn request_count(&self) -> usize
Get the number of requests received
Sourcepub fn get_requests(&self) -> Vec<CapturedRequest>
pub fn get_requests(&self) -> Vec<CapturedRequest>
Get all captured requests
Sourcepub fn get_request_bodies_as_string(&self) -> Vec<String>
pub fn get_request_bodies_as_string(&self) -> Vec<String>
Get all captured request bodies as strings (for JSON verification)
Sourcepub fn get_request_bodies_as_json(&self) -> Vec<Value>
pub fn get_request_bodies_as_json(&self) -> Vec<Value>
Parse all captured request bodies as JSON
Sourcepub async fn wait_for_requests(&self, count: usize, timeout: Duration) -> bool
pub async fn wait_for_requests(&self, count: usize, timeout: Duration) -> bool
Wait for at least N requests with a timeout