Streamling binary execution helpers.
Structs
- Streamling
Output - Output from running streamling with captured stdout/stderr
Functions
- run_
streamling - Run the streamling binary with the given pipeline file
- run_
streamling_ raw - Run streamling and return raw output, even on failure
- run_
streamling_ with_ capture - Run streamling and capture stdout/stderr for inspection
- run_
streamling_ with_ capture_ and_ limit - Run streamling with capture and a record limit
- run_
streamling_ with_ limit - Run streamling and wait for it to process a specific number of records This is useful for tests that need streamling to run until a condition is met